<?php
if (!defined('DC_CONTEXT_ADMIN')) { exit; }

if (!dcCore::app()->blog->settings->randomPost->randomPost_category) {
    try {
        dcCore::app()->blog->settings->addNamespace('randomPost');
        dcCore::app()->blog->settings->randomPost->put(
            'randomPost_category',
            randomPost::allCatID,
            'text',
            'Category limitation when selecting a random post (only from template functions)'
        );
        if (dcCore::app()->blog->settings->randompost->randompost_category) {
            // Backport the setting value from the previously incorrectly named namespace
            dcCore::app()->blog->settings->randomPost->randomPost_category = dcCore::app()->blog->settings->randompost->randompost_category;
            dcCore::app()->blog->settings->randompost->drop('randompost_category');
        }
    } catch (Exception $e) {
        dcCore::app()->error->add($e->getMessage());
    }
}

if (isset($_POST['randomPostURL'])) {
    try {
        dcCore::app()->blog->settings->addNamespace('randomPost');
        dcCore::app()->blog->settings->randomPost->put('randomPostURL', $_POST['randomPostURL'], 'string', 'Prefix for the URL redirecting to a random post');
        dcCore::app()->blog->settings->randomPost->put('randomPostStaticURL', $_POST['randomPostStaticURL'], 'string', 'Prefix for the URL displaying a random post');
        dcCore::app()->blog->settings->randomPost->put('randomPost_category', $_POST['randomPost_category'], 'string', 'Category limitation when selecting a random post (only from template functions)');

        dcCore::app()->blog->triggerBlog();
        dcPage::addSuccessNotice(__('Settings have been successfully updated.'));
        http::redirect(dcCore::app()->admin->getPageURL());
    } catch (Exception $e) {
        dcCore::app()->error->add($e->getMessage());
    }
}

?>
<html>
<head>
  <title><?php echo __('Random Post plugin'); ?></title>
  <?php echo dcPage::jsPageTabs('options'); ?>
</head>
<body>
<?php
echo dcPage::breadcrumb(
    [
        html::escapeHTML(dcCore::app()->blog->name) => '',
        __('Random Post plugin')                    => '',
    ]
);
echo dcPage::notices();
?>
<div class="multi-part" id="options" title="<?php echo __('Options'); ?>">
    <form method="post" action="<?php echo dcCore::app()->admin->getPageURL();?>">
        <p><label for="randomPostURL"><?php echo __('Prefix for the URL redirecting to a random post:'); ?></label> <?php echo form::field('randomPostURL', 30, 128, html::escapeHTML(dcCore::app()->blog->settings->randomPost->randomPostURL)); ?></p>
        <p><label for="randomPostStaticURL"><?php echo __('Prefix for the URL displaying a random post:'); ?></label> <?php echo form::field('randomPostStaticURL', 30, 128, html::escapeHTML(dcCore::app()->blog->settings->randomPost->randomPostStaticURL)); ?></p>
        <p><label for="randomPost_category"><?php echo __('Category limitation when selecting a random post (only from template functions):'); ?></label> <?php echo form::field('randomPost_category', 30, 128, html::escapeHTML(dcCore::app()->blog->settings->randomPost->randomPost_category)); ?></p>
        <p><?php echo dcCore::app()->formNonce(); ?><input type="submit" value="<?php echo __('Save'); ?>" /></p>
    </form>
</div>

<div class="multi-part" id="usage" title="<?php echo __('Usage'); ?>">
<h3><?php echo __('Usage');?></h3>
<p><?php echo sprintf(__("In your template, just create a link with %s as a destination. When your visitors'll click on that link, they'll be redirect to a random post from your blog."), '<kbd>{{tpl:RandomRedirURL}}</kbd>'); ?></p>
<p><?php echo sprintf(__("Or, if you prefer, you can also use it as a widget. The link will be enclosed in a %s with class %s and displayed as a %s."), '<kbd>&lt;div&gt;</kbd>', '<kbd>randompost</kbd>', '<kbd>&lt;li&gt;</kbd>'); ?></p>
<h3><?php echo __('Advanced usage');?></h3>
<p><?php echo '<strong>'.__('Note:').'</strong> '.__('I advise you strongly <strong>not</strong> to use these advanced techniques on every page of your blog.').' '.
__("Doing so will result in two more SQL requests for every page views, which might slow down your site to a crawl. You've been warned.");?></p>
<p><?php echo __('You can display both an excerpt and the title from the post, either with the widget options or the template functions.');?></p>
<ul>
<li><?php echo __('Using the widgets options:');?>
<dl>
  <dt><?php echo __('Title:');?></dt><dd><?php echo __('Title of the block displayed in the sidebar, or link text if you use redirection.');?></dd>
  <dt><?php echo __('Use redirection');?></dt><dd><?php echo sprintf(__('Use a %s URL for redirection.'), '<kbd>/random</kbd>').' '.__('This is the prefered method, as the needed database requests will only be executed when your users click on the link.');?></dd>
  <dt><?php echo __('Display an excerpt from the post');?></dt><dd><?php echo __("Will display the excerpt from the post, or the post's content if there's no excerpt.");?></dd>
  <dt><?php echo __('Excerpt maximum length (in characters)');?></dt><dd><?php echo __('Limit the displayed excerpt to a certain maximum length. Use 0 if you want to display the full excerpt.');?></dd>
  <dt><?php echo __('HTML tags allowed in the output');?></dt><dd><?php echo sprintf(__("Specify the HTML tags you want to allow in the excerpt. You can put multiple tags, for example: %s"), '<kbd>&lt;img&gt;&lt;a&gt;</kbd>');?></dd>
  <dt><?php echo __('Home page only');?></dt><dd><?php echo __('Display the link to the random post only on the home page.');?></dd>
  <dt><?php echo __('Restrict to category');?></dt><dd><?php echo __('With this option, you can restrict the posts to one category only.').' '.__('Choose "All categories" if you don\'t want this limit.');?></dd>
</dl>
</li><li><?php echo __('Using the template functions:');?>
<dl>
  <dt><kbd>{{tpl:RandomRedirURL}}</kbd></dt><dd><?php echo __('Use this function as the destination of a link.').' '.__('This is the prefered method, as the needed database requests will only be executed when your users click on the link.');?></dd>
  <dt><kbd>&lt;tpl:RandomPost&gt;</kbd></dt><dd><?php echo __('Start of a template block. It selects a random post, which can then be accessed and displayed with the next functions.');?></dd>
  <dt><kbd>{{tpl:RandomPostURL}}</kbd></dt><dd><?php echo __('Returns the URL of the selected post.');?></dd>
  <dt><kbd>{{tpl:RandomPostTitle}}</kbd></dt><dd><?php echo __('Returns the title of the selected post.');?></dd>
  <dt><kbd>{{tpl:RandomPostExcerpt}}</kbd></dt><dd><?php echo __("Returns the excerpt (or content it there's no excerpt) of the selected post.").' '.
  sprintf(__('Can take one attribute, %s, which indicates the maximum length for the excerpt displayed.'), '<kbd>max_length</kbd>').' '.
  sprintf(__('Use 0 for %s to disable this truncation (the default is 200 characters).'), '<kbd>max_length</kbd>');?></dd>
</dl>
</li>
</ul>
<p><?php echo sprintf(__('Both the %s and %s template functions can take one attribute: %s.'), '<kbd>&lt;tpl:RandomPost&gt;</kbd>', '<kbd>{{tpl:RandomRedirURL}}</kbd>', '<kbd>limit_to_category_id</kbd>').' '.
__('This attribute takes a numeric value: the ID of a category.').' '.__('If you use that attribute, all the posts randomly selected will belong to the given category.');?></p>
<p><?php echo '<strong>'.__('Note:').'</strong> '.__('In the widget, the options "Use redirection" and "Display an excerpt from the post" are mutually exclusive.').
' '.__('If you check both boxes, the option "Use redirection" will take precedence.'); ?></p>
</div>

<div class="multi-part" id="changelog" title="<?php echo __('Changelog'); ?>">
<h3>Version 1.1.0</h3>
<p><?php echo sprintf(__('Released on %s'), '2023-02-05'); ?></p>
<ul>
<li><?php echo __("Added the possibility to edit the URL prefixes in the plugin's admin page."); ?></li>
<li><?php echo __("Fixed the bug where installing a new version of the plugin emptied the settings for the URL prefixes"); ?></li>
</ul>
<h3>Version 1.0.1</h3>
<p><?php echo sprintf(__('Released on %s'), '2023-01-16'); ?></p>
<ul>
<li><?php echo __('Fixed the invalid link to the post in the widget.'); ?></li>
</ul>
<h3>Version 1.0.0</h3>
<p><?php echo sprintf(__('Released on %s'), '2022-12-25'); ?></p>
<ul>
<li><?php echo __('Made it compatible with Dotclear version 2.24.'); ?></li>
</ul>
<h3>Version 0.9.2</h3>
<p><?php echo sprintf(__('Released on %s'), '2012-10-11'); ?></p>
<ul>
<li><?php echo __('Corrected a typo in the name of a setting.'); ?></li>
<li><?php echo __('Made it compatible with the latest PHP and Dotclear versions.'); ?></li>
</ul>
<h3>Version 0.9.1a</h3>
<p><?php echo sprintf(__('Released on %s'), '2010-07-03'); echo ' '.__('(Port of the features from version 0.8.1 to the Dotclear 2.2 branch)'); ?></p>
<ul>
<li><?php echo __('A new URL handler which displays a different post on each reload from the browser.'); ?></li>
<li><?php echo __('Possibility to change the URL prefixes used via about:config.'); ?></li>
</ul>
<h3>Version 0.9.0</h3>
<p><?php echo __('No public release'); ?></p>
<ul>
<li><?php echo __('Compatible with Dotclear 2.2.'); ?></li>
</ul>
<h3>Version 0.8.1a</h3>
<p><?php echo sprintf(__('Released on %s'), '2010-02-01'); ?></p>
<ul>
<li><?php echo __('A new URL handler which displays a different post on each reload from the browser.'); ?></li>
<li><?php echo __('Possibility to change the URL prefixes used via about:config.'); ?></li>
</ul>
<h3>Version 0.8</h3>
<p><?php echo sprintf(__('Released on %s'), '2009-08-31'); ?></p>
<ul>
<li><?php echo sprintf(__('Compatible with the %s template tag.'), '<kbd>&lt;tpl:widget&gt;</kbd>'); ?></li>
<li><?php echo __('Compatible with PHP 5.3.'); ?></li>
</ul>
<h3>Version 0.7-alpha</h3>
<p><?php echo sprintf(__('Private release on %s'), '2009-01-11'); ?></p>
<ul>
<li><?php echo __('Now allows to specify some tags which should not be stripped from the displayed excerpt.'); ?></li>
</ul>
<h3>Version 0.6</h3>
<p><?php echo sprintf(__('Released on %s'), '2007-08-06'); ?></p>
<ul>
<li><?php echo sprintf(__('Corrected some error messages which appeared when the reporting level of PHP included %s.'), 'E_NOTICE'); ?></li>
</ul>
<h3>Version 0.5</h3>
<p><?php echo sprintf(__('Released on %s'), '2007-01-29'); ?></p>
<ul>
<li><?php echo __('You can now limit the posts randomly chosen in one category (both with the widget and the templating functions).'); ?></li>
<li><?php echo __('Added one notice regarding the incompatibility of two widget options.'); ?></li>
<li><?php echo __('Corrected a few typos here and there.'); ?></li>
</ul>
<h3>Version 0.4</h3>
<p><?php echo sprintf(__('Released on %s'), '2007-01-28'); ?></p>
<ul>
<li><?php echo __('Added the possibility to display the randomly chosen post title and excerpt (both with template functions and the widget).'); ?></li>
<li><?php echo sprintf(__('Changed the name of the template function. %s is now called %s.'), '<kbd>{{tpl:RandomPostURL}}</kbd>', '<kbd>{{tpl:RandomRedirURL}}</kbd>'); ?></li>
<li><?php echo sprintf(__('Changed the %s CSS id to a class.'),'<kbd>randompost</kbd>'); ?></li>
</ul>
<h3>Version 0.3</h3>
<p><?php echo sprintf(__('Released on %s'), '2007-01-24'); ?></p>
<ul>
<li><?php echo __('Preceding versions did not work on PostgreSQL. The SQL requests should now be DB independant.'); ?></li>
<li><?php echo __('The SQL requests were rewritten to be less a burden on medium and big size databases.'); ?></li>
</ul>
<h3>Version 0.2a</h3>
<p><?php echo sprintf(__('Released on %s'), '2007-01-22'); ?></p>
<ul>
<li><?php echo __('Houston, we have an icon!'); ?></li>
</ul>
<h3>Version 0.2</h3>
<p><?php echo sprintf(__('Released on %s'), '2007-01-21'); ?></p>
<ul>
<li><?php echo __('The random URL is now also available as a widget.'); ?></li>
</ul>
<h3>Version 0.1</h3>
<p><?php echo sprintf(__('Released on %s'), '2007-01-21'); ?></p>
<ul>
<li><?php echo __('First release.'); ?></li>
<li><?php echo __('The random URL is available only through a template function.'); ?></li>
</ul>
</div>
</body>
</html>
